@@ -4,10 +4,14 @@ from logging import StreamHandler
 from queue import Queue
 from typing import Any, List, Optional
 
-from picologging.handlers import QueueHandler, QueueListener
-
+from starlite.exceptions import MissingDependencyException
 from starlite.logging.utils import resolve_handlers
 
+try:
+    from picologging.handlers import QueueHandler, QueueListener
+except ImportError as e:
+    raise MissingDependencyException("picologging is not installed") from e
+
 
 class QueueListenerHandler(QueueHandler):  # type: ignore[misc]
     def __init__(self, handlers: Optional[List[Any]] = None) -> None:
